@@ -3,7 +3,7 @@ package Acme::CPANModules::Sudoku;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2021-01-12'; # DATE
 our $DIST = 'Acme-CPANModules-Sudoku'; # DIST
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 
 use strict;
 use Acme::CPANModulesUtil::Misc;
@@ -20,10 +20,10 @@ playable Sudoku game on CPAN.
 
 **Playing**
 
-<pm::Games::Sudoku::CLI>. Since it's CLI (prompt-based) instead of TUI, it's not
+<pm:Games::Sudoku::CLI>. Since it's CLI (prompt-based) instead of TUI, it's not
 really convenient to play unless you're a CLI freak.
 
-<pm::Games::Sudoku::Component::TkPlayer>. It's GUI and barely playable, but
+<pm:Games::Sudoku::Component::TkPlayer>. It's GUI and barely playable, but
 clunky and not pretty. There's no visual indicator for separating the larger 3x3
 boxes.
 
@@ -82,7 +82,7 @@ Acme::CPANModules::Sudoku - Sudoku-related modules on CPAN
 
 =head1 VERSION
 
-This document describes version 0.001 of Acme::CPANModules::Sudoku (from Perl distribution Acme-CPANModules-Sudoku), released on 2021-01-12.
+This document describes version 0.002 of Acme::CPANModules::Sudoku (from Perl distribution Acme-CPANModules-Sudoku), released on 2021-01-12.
 
 =head1 DESCRIPTION
 
@@ -96,10 +96,10 @@ playable Sudoku game on CPAN.
 
 B<Playing>
 
-<pm::Games::Sudoku::CLI>. Since it's CLI (prompt-based) instead of TUI, it's not
+L<Games::Sudoku::CLI>. Since it's CLI (prompt-based) instead of TUI, it's not
 really convenient to play unless you're a CLI freak.
 
-<pm::Games::Sudoku::Component::TkPlayer>. It's GUI and barely playable, but
+L<Games::Sudoku::Component::TkPlayer>. It's GUI and barely playable, but
 clunky and not pretty. There's no visual indicator for separating the larger 3x3
 boxes.
 
@@ -135,6 +135,10 @@ L<Games::YASudoku>
 
 =over
 
+=item * L<Games::Sudoku::CLI>
+
+=item * L<Games::Sudoku::Component::TkPlayer>
+
 =item * L<Spreadsheet::HTML::Presets::Sudoku>
 
 =item * L<Games::Sudoku::Lite>
